@@ -1,7 +1,9 @@
 package Pod::Weaver::Plugin::WordList;
 
-our $DATE = '2020-08-23'; # DATE
-our $VERSION = '0.062'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-09-15'; # DATE
+our $DIST = 'Pod-Weaver-Plugin-WordList'; # DIST
+our $VERSION = '0.063'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -153,7 +155,7 @@ _
         push @pod, "The statistics is available in the C<\%STATS> package variable.\n\n";
 
         $self->add_text_to_section(
-            $document, join("", @pod), 'STATISTICS',
+            $document, join("", @pod), 'WORDLIST STATISTICS',
             {
                 after_section => ['SYNOPSIS'],
                 before_section => 'DESCRIPTION',
@@ -192,7 +194,7 @@ Pod::Weaver::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.062 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2020-08-23.
+This document describes version 0.063 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2020-09-15.
 
 =head1 SYNOPSIS
 
@@ -209,7 +211,7 @@ it does the following:
 
 =item * Add a Synopsis section (if doesn't already exist) showing how to use the module
 
-=item * Add Statistics section showing statistics from C<%STATS> (which can be generated by DZP:WordList)
+=item * Add WordList Statistics section showing statistics from C<%STATS> (which can be generated by DZP:WordList)
 
 =back
 
